<?php
/**
 * Mandae integration with the REST API.
 *
 * @package WooCommerce_Mandae/Classes
 * @since   3.0.0
 * @version 1.0.1
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * WC_Mandae_REST_API class.
 */
class WC_Mandae_Install
{

    /**
     * Get version.
     *
     * @return string
     */
    private static function get_version()
    {
        return get_option('woocommerce_mandae_version');
    }

    /**
     * Update version.
     */
    private static function update_version()
    {
        update_option('woocommerce_mandae_version', WC_Mandae::VERSION);
    }

    /**
     * Upgrade to 3.0.0.
     */
    public static function upgrade_300()
    {
        global $wpdb;

        $version = self::get_version();

        if (empty($version)) {
            $wpdb->query("UPDATE {$wpdb->postmeta} SET meta_key = '_mandae_tracking_code' WHERE meta_key = 'mandae_tracking';");
        }
    }

    /**
     * Upgrade to 3.0.0 while using WooCommerce 2.6.0.
     */
    public static function upgrade_300_from_wc_260()
    {
        if ($old_options = get_option('woocommerce_mandae_settings')) {
            if (isset($old_options['tracking_history'])) {
                $integration_options = get_option('woocommerce_mandae-integration_settings', array(
                    'general_options' => '',
                    'tracking' => '',
                    'enable_tracking' => 'no',
                    'tracking_debug' => 'no',
                ));

                $integration_options['enable_tracking'] = $old_options['tracking_history'];
                update_option('woocommerce_mandae-integration_settings', $integration_options);

                unset($old_options['tracking_history']);
                update_option('woocommerce_mandae_settings', $old_options);
            }

            if ('no' === $old_options['enabled']) {
                delete_option('woocommerce_mandae_settings');
            }
        }
    }
}
